%% Portal! - Trajectory analysis
%
% Final logfile variables (variable eprimedata)
%   1 - 'Subject'
%   2 - 'Group'
%   3 - 'Block'
%   4 - 'Trial'
%   5 - 'BlockTrial'
%   6 - 'FreeForced'
%   7 - 'Compatibility'
%   8 - 'TarDir'
%   9 - 'DT'
%  10 - 'RT'
%  11 - 'RTx'
%  12 - 'RTy'
%  13 - 'MT'
%  14 - 'MTx'
%  15 - 'MTy'
%  16 - 'RespDir'
%  17 - 'ErrorType'
%  18 - 'OK'
%  19 - 'FreeForced_N1'
%  20 - 'Comp_N1'
%  21 - 'TarDir_N1'
%  22 - 'ErrorType_N1'
%  23 - 'OK_N1'
%  24 - 'ZDT'
%  25 - 'ZRT'
%  26 - 'ZMT'
%  27 - 'MAD'
%  28 - 'AUC'
%  29 - 'Curv1'
%  30 - 'Curv2'
%  31 - 'TTPVeloc'
%  32 - 'Z_Filter'


% Get trajectory data
cd MData_Exp1_and_2;
sbjcts = dir('*.dat');
cd ..;

% Get and recode trial data
cd ..;
eprimedata = dlmread('Portal_Ges.dat','\t',1,0);
cd Tracking;
eprimedata(:,5) = repmat([1:56].',5*size(sbjcts,1),1);
% Compute and preallocate columns for N1-Variables,
% zDT, zRT, zMT, MAD, AUC, and Curv1, Curv2, and
% TimeToPeakVelocity.
eprimedata(2:end,end+1) = eprimedata(1:end-1,6); % FreeForced_N1
eprimedata(2:end,end+1) = eprimedata(1:end-1,7); % Comp_N1
eprimedata(2:end,end+1) = eprimedata(1:end-1,8); % TarDir_N1
eprimedata(2:end,end+1) = eprimedata(1:end-1,17); % ErrorType_N1
eprimedata(2:end,end+1) = eprimedata(1:end-1,18); % OK_N1
eprimedata(1:56:end,19:23) = -99;
eprimedata(:,end+1:end+8) = -99;
eprimedata(:,end+1)     = 1; % z-Filter

%% Prepare analysis
%
% Preallocation
mean_x1_sav = [];
mean_x2_sav = [];
mean_y1_sav = [];
mean_y2_sav = [];

allthemads_1 = [];
allthemads_2 = [];

% Ideal trajectory slope
starty = (768/2+250-3);
finaly = starty - (768/2-150);
finalx = 250;
slope = finaly / finalx;

% Z-Correction
z_crit = 2.5;

%% Prepare trial data.
for sbjctnr = [1:41]%[11:20,31:37]%[1:10,21:30]%1:size(sbjcts,1)

% Perform z-correction  
for icomp = -1:2:1
zindex = (eprimedata(:, 1) == sbjctnr) & (eprimedata(:, 3) >= 2) & ...
         (eprimedata(:,18) == 1)       & (eprimedata(:,23) == 1) & ...
         (eprimedata(:, 7) == icomp);  
eprimedata(zindex,25) = (eprimedata(zindex,10) - ...
    mean(eprimedata(zindex,10))) / std(eprimedata(zindex,10));
eprimedata(zindex,26) = (eprimedata(zindex,13) - ...
    mean(eprimedata(zindex,13))) / std(eprimedata(zindex,13));
clear zindex;
end;
clear icomp;

% Get trajectory data
sbjctdata = dlmread(['MData_Exp12\' sbjcts(sbjctnr).name],'\t',1,0);

% Preallocate trajectory variables
x_traj_aggr{sbjctnr,1} = []; %#ok<*SAGROW>
y_traj_aggr{sbjctnr,1} = [];
x_traj_aggr{sbjctnr,2} = [];
y_traj_aggr{sbjctnr,2} = [];

allthemads_1_tmp = [];
allthemads_2_tmp = [];

for blocknr = 2:5
for blocktrl = 1:56

%trialnr = 13;

trialnr  = (blocknr-1) * 56 + blocktrl;
trlstats = eprimedata((eprimedata(:,1)==sbjctnr) & ...
    (eprimedata(:,4)==trialnr),:);
trlindex = find((eprimedata(:,1)==sbjctnr) & ...
    (eprimedata(:,4)==trialnr),1);

isinteresting = (sbjctdata(:,2)==trialnr);

if (max(isinteresting) < 1) || (trlstats(1,18) < 1)         || ...
   (trlstats(1,23) < 1)     || (abs(trlstats(1,25)) >= 2.5) || ...
   (trlstats(1, 2) < 1)     || (abs(trlstats(1,26)) >= 2.5);
  
else

tempdata = sbjctdata(isinteresting,:);




% Remove dwell time data
tempdata(:,4) = tempdata(:,4)-tempdata(1,4);
% Strip off RT dwell data
preRT = find(tempdata(:,4) > trlstats(1,10),1);
% Set starting point
tempdata(:,6) = tempdata(:,6) - 512;
% Mirror x-data?
if trlstats(1,8) == -1
    tempdata(:,6) = (-1) * tempdata(:,6);
end;
% plot(tempdata(:,6),tempdata(:,7));
%plot(tempdata(:,6),tempdata(:,7));
%pause
tempdata(:,7) = starty - tempdata(:,7);
start_x = tempdata(1,6);
start_y = tempdata(1,7);
tempdata = tempdata(max(preRT-5,1):end,:);
clear preRT;

plot(tempdata(:,6),tempdata(:,7))
% Save trial plot
if trlstats(1,7) < 0
    condindex = 1;
else
    condindex = 2;
end;
saveas(gca,['SingleSubjPlots\S' num2str(sbjctnr) ...
    '_C' num2str(condindex) '_B' num2str(blocknr) ...
    '_T' num2str(blocktrl)],'bmp');


min_datapoints = 2;
if size(tempdata,1) >= min_datapoints




    
% Interpolate.
tempdata(:,4) = tempdata(:,4) - tempdata(1,4);
time = tempdata(:,4) ./ tempdata(end,4) * 100;
x_int = interp1(time,tempdata(:,6),[0:100],'linear');
y_int = interp1(time,tempdata(:,7),[0:100],'linear');

% plot(x_int,y_int);
% plot(x_int,y_int,[0,300],[0,300*slope]);

% Mad
% plot(x_int,y_int,[0,61.61,306],[0,112.38,467])

slope2 = (y_int(end)-start_y) / (x_int(end)-start_x); 
inter2 = y_int(end) - slope2 * x_int(end);

% [adtmp adtmpdir adtmpcoo] = comp_ad(x_int,y_int,slope,0);

[adtmp adtmpdir adtmpcoo] = comp_ad(x_int,y_int,slope2,inter2);

adtmp2 = adtmp(find(adtmp==max(adtmp),1)) * ...
    adtmpdir(find(adtmp==max(adtmp),1));
eprimedata(trlindex,27) = adtmp2;



% AUC
auctmp = comp_auc(x_int,y_int,slope2,inter2);
eprimedata(trlindex,28) = auctmp(end);
% figure(2)
% plot(auctmp)

% Curv 1
opt  = ((x_int(end) - x_int(1)).^2 + (y_int(end) - y_int(1)).^2).^0.5;
real = ((x_int(2:end) - x_int(1:end-1)).^2 + (y_int(2:end) - y_int(1:end-1)).^2).^0.5;
eprimedata(trlindex,29) = sum(real) ./ opt;

% Curv 2
dy1 = tempdata(2:end-1,7)-tempdata(1:end-2,7);
dx1 = tempdata(2:end-1,6)-tempdata(1:end-2,6);
dy2 = tempdata(3:end, 7)-tempdata(2:end-1,7 );
dx2 = tempdata(3:end, 6)-tempdata(2:end-1,6 );
dd  = (dy2 ./ dx2) - (dy1 ./ dx1);
dd(dd== Inf) = NaN;
dd(dd==-Inf) = NaN;
eprimedata(trlindex,30) = nanvar(dd);

% Time to peak velocity
velocity = real(2:end)-real(1:end-1);
eprimedata(trlindex,31) = find(velocity==max(velocity),1);

% Save data.
if trlstats(1,7) < 0
    condindex = 1;
else
    condindex = 2;
end;
x_traj_aggr{sbjctnr,condindex} =     ...
    [x_traj_aggr{sbjctnr,condindex}; ...
    x_int];
y_traj_aggr{sbjctnr,condindex} =     ...
    [y_traj_aggr{sbjctnr,condindex}; ...
    y_int];

% Clear trial variables;
clear time;
clear x_int;
clear y_int;
clear tempdata;
clear adtmp;
clear adtmp2;
clear adtmpcoo;
clear adtmpdir;
clear auctmp;
clear condindex;
clear dd;
clear dx1;
clear dx2;
clear dy1;
clear dy2;
clear opt;
clear real;
clear trlindex;
clear trlstats;
clear velocity;

end; % No data left after RT correction
end; % Isinteresting

end; % Trial loop
end; % Block loop


mean_x(1:101,1) = mean(x_traj_aggr{sbjctnr,1},1);
mean_x(1:101,2) = mean(x_traj_aggr{sbjctnr,2},1);
mean_y(1:101,1) = mean(y_traj_aggr{sbjctnr,1},1);
mean_y(1:101,2) = mean(y_traj_aggr{sbjctnr,2},1);

mean_x1_sav = [mean_x1_sav; mean_x(1:101,1).']; %#ok<*AGROW>
mean_x2_sav = [mean_x2_sav; mean_x(1:101,2).'];
mean_y1_sav = [mean_y1_sav; mean_y(1:101,1).'];
mean_y2_sav = [mean_y2_sav; mean_y(1:101,2).'];

allthemads_1 = [allthemads_1; mean(allthemads_1_tmp)];
allthemads_2 = [allthemads_2; mean(allthemads_2_tmp)];

disp(['Subject ' num2str(sbjctnr) ' done.']);

% if sbjctnr == 1
%     a = mean_x(:,1);
% figure(sbjctnr);
% plot(mean_x(:,1),mean_y(:,1),'r+',mean_x(:,2),mean_y(:,2),'b--')
% end;

% Clean up workspace.
clear trialnr;
clear blocktrl;
clear blocknr;
clear isinteresting;
clear sbbjctdata;
clear mean_x;
clear mean_y;

end; % Subject loop

% Clean up workspace.
clear sbjctdata;
clear tempdata;
clear trialnr;
clear z_crit;
clear sbjctnr;

% deltamad = allthemads_1 - allthemads_2;

%% Save summary logfile
header = {'Subject', 'Group', 'Block', 'Trial',   ...
    'BlockTrial', 'FreeForced', 'Compatibility',  ...
    'TarDir', 'DT', 'RT', 'RTx', 'RTy', 'MT',     ...
    'MTx', 'MTy', 'RespDir', 'ErrorType', 'OK',   ... % New variables
    'FreeForced_N1', 'Comp_N1', 'TarDir_N1',      ...
    'ErrorType_N1', 'OK_N1', 'ZDT', 'ZRT', 'ZMT', ...
    'MAD', 'AUC', 'Curv1', 'Curv2', 'TTPVeloc',   ...
    'Z_Filter'};
cd ..;
dlmcell('Portal_Ges_recoded.dat',header);
clear header;
dlmwrite('Portal_Ges_recoded.dat', eprimedata,   ...
    '-append', 'delimiter', '\t', 'newline', 'pc');
